from pprint import pprint

import fastlabel

client = fastlabel.Client()

dataset_object_import_histories = client.get_dataset_object_import_histories(
    dataset_version_id="YOUR_DATASET_VERSION_ID"
)
pprint(dataset_object_import_histories)



from pprint import pprint

import fastlabel

client = fastlabel.Client()

dataset_object = client.create_image_dataset_object(
    dataset_version_id="YOUR_DATASET_VERSION_ID",
    name="NAME",
    file_path="FILE_PATH",
)
pprint(dataset_object)



from pprint import pprint

import fastlabel

client = fastlabel.Client()

dataset_object_annotations = client.get_dataset_object_annotations(
    dataset_object_id="YOUR_DATASET_OBJECT_ID",
)
pprint(dataset_object_annotations)



from pprint import pprint

import fastlabel

client = fastlabel.Client()

dataset_version = client.create_dataset_version(
    dataset_id="YOUR_DATASET_ID",
    version="version",
)
pprint(dataset_version)



import fastlabel

client = fastlabel.Client()

client.delete_dataset_objects(
    dataset_id="YOUR_DATASET_ID",
    dataset_object_ids=[
        "YOUR_DATASET_OBJECT_ID_1",
        "YOUR_DATASET_OBJECT_ID_2",
    ],
)
